# std_srvs

This package provides several service definitions for standard but simple ROS services.

For more information about ROS 2 interfaces, see [docs.ros.org](https://docs.ros.org/en/rolling/Concepts/About-ROS-Interfaces.html).

## Services (.srv)
* [Empty.srv](srv/Empty.srv): A service containing an empty request and response.
* [SetBool.srv](srv/SetBool.srv): Service to set a boolean state to true or false, for enabling or disabling hardware for example.
* [Trigger.srv](srv/Trigger.srv): Service with an empty request header used for triggering the activation or start of a service.


## Quality Declaration
This package claims to be in the **Quality Level 1** category, see the [Quality Declaration](QUALITY_DECLARATION.md) for more details.
